@@ -3,27 +3,29 @@
 import json
 import os
 import re
-import pytest
-import six
 import sys
-try:
-    from unittest.mock import MagicMock
-except ImportError:
-    from unittest.mock import MagicMock
-from ansible_runner import Runner
+import time
 
+from test.utils.common import iterate_timeout
+
+import pytest
+
+from ansible_runner import Runner, run
 from ansible_runner.exceptions import AnsibleRunnerException
 
 
-@pytest.mark.serial
+@pytest.mark.xfail(reason='Test is unstable')
 def test_password_prompt(rc):
-    rc.command = [sys.executable, '-c' 'import time; print(input("Password: "))']
+    rc.command = [sys.executable, '-c', 'import time; print(input("Password: "))']
     rc.expect_passwords[re.compile(r'Password:\s*?$', re.M)] = '1234'
     status, exitcode = Runner(config=rc).run()
     assert status == 'successful'
     assert exitcode == 0
-    with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
-        assert '1234' in f.read()
+    # stdout file can be subject to a race condition
+    for _ in iterate_timeout(30.0, 'stdout file to be written with 1234 in it', interval=0.2):
+        with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
+            if '1234' in f.read():
+                break
 
 
 def test_run_command(rc):
@@ -40,8 +42,6 @@ def test_run_command(rc):
 
 def test_run_command_with_unicode(rc):
     expected = '"utf-8-䉪ቒ칸ⱷ?噂폄蔆㪗輥"'
-    if six.PY2:
-        expected = expected.decode('utf-8')
     rc.command = ['echo', '"utf-8-䉪ቒ칸ⱷ?噂폄蔆㪗輥"']
     rc.envvars = {"䉪ቒ칸": "蔆㪗輥"}
     rc.prepare_env()
@@ -53,11 +53,11 @@ def test_run_command_with_unicode(rc):
         assert data.get('command') == ['echo', expected]
         assert 'cwd' in data
         assert isinstance(data.get('env'), dict)
-        assert u"䉪ቒ칸" in data.get('env')
+        assert "䉪ቒ칸" in data.get('env')
 
 
-def test_run_command_finished_callback(rc):
-    finished_callback = MagicMock()
+def test_run_command_finished_callback(rc, mocker):
+    finished_callback = mocker.MagicMock()
     rc.command = ['sleep', '1']
     runner = Runner(config=rc, finished_callback=finished_callback)
     status, exitcode = runner.run()
@@ -85,7 +85,7 @@ def test_run_command_explosive_cancel_callback(rc):
 
 
 def test_run_command_cancel_callback(rc):
-    def cancel(*args):
+    def cancel(*args):  # pylint: disable=W0613
         return True
     rc.command = ['sleep', '1']
     runner = Runner(config=rc, cancel_callback=cancel)
@@ -153,7 +153,7 @@ def test_run_command_events_missing(rc):
     status, exitcode = runner.run()
     assert status == 'successful'
     assert exitcode == 0
-    assert list(runner.events) == []
+    assert not list(runner.events)
 
 
 def test_run_command_stdout_missing(rc):
@@ -184,16 +184,17 @@ def test_run_command_ansible(rc):
     status, exitcode = runner.run()
     assert status == 'successful'
     assert exitcode == 0
-    assert list(runner.events) != []
+    assert list(runner.events)
     assert runner.stats != {}
-    assert list(runner.host_events('localhost')) != []
-    stdout = runner.stdout
-    assert stdout.read() != ""
+    assert list(runner.host_events('localhost')), repr(list(runner.events))
+    with runner.stdout as f:
+        stdout = f.read()
+    assert stdout != ""
 
 
-def test_run_command_ansible_event_handler(rc):
-    event_handler = MagicMock()
-    status_handler = MagicMock()
+def test_run_command_ansible_event_handler(rc, mocker):
+    event_handler = mocker.MagicMock()
+    status_handler = mocker.MagicMock()
     rc.module = "debug"
     rc.host_pattern = "localhost"
     rc.prepare()
@@ -255,7 +256,7 @@ def test_set_fact_cache(rc):
     rc.host_pattern = "localhost"
     rc.prepare()
     runner = Runner(config=rc)
-    runner.set_fact_cache('localhost', dict(message='hello there'))
+    runner.set_fact_cache('localhost', {'message': 'hello there'})
     status, exitcode = runner.run()
     assert status == 'successful'
     assert exitcode == 0
@@ -270,9 +271,25 @@ def test_set_extra_vars(rc):
     rc.module = "debug"
     rc.module_args = "var=test_extra_vars"
     rc.host_pattern = "localhost"
-    rc.extra_vars = dict(test_extra_vars='hello there')
+    rc.extra_vars = {'test_extra_vars': 'hello there'}
     rc.prepare()
     runner = Runner(config=rc)
-    status, exitcode = runner.run()
-    with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
-        assert 'hello there' in f.read()
+    runner.run()
+    # stdout file can be subject to a race condition
+    for _ in iterate_timeout(30.0, 'stdout file to be written with "hello there" in it', interval=0.2):
+        with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
+            if 'hello there' in f.read():
+                break
+
+
+# regression test for https://github.com/ansible/ansible-runner/issues/1330
+def test_pexpect_timeout(project_fixtures):
+    r = run(
+        private_data_dir=str(project_fixtures / 'pexpect_timeout_data_loss'),
+        playbook='pb.yml',
+        settings={"pexpect_timeout": 0.1},  # set the pexpect timeout very low
+        cancel_callback=lambda: time.sleep(3) or False,  # induce enough delay in the child polling loop that the child will exit before being polled again
+    )
+
+    # ensure we got playbook_on_stats; if pexpect ate it, we won't...
+    assert any(ev for ev in r.events if ev.get('event', None) == 'playbook_on_stats')
