@@ -1,13 +1,13 @@
 """ Ensure the generation of container volume mounts is handled
 predictably and consistently """
 
+# pylint: disable=W0212,W0621
+
 import os
-import pytest
-
-from unittest.mock import patch
-
 from typing import NamedTuple
 
+import pytest
+
 from ansible_runner.config._base import BaseConfig
 from ansible_runner.exceptions import ConfigurationError
 
@@ -60,47 +60,47 @@ def resolve_path(path):
     return os.path.abspath(os.path.expanduser(os.path.expandvars(path)))
 
 
-def generate_volmount_args(src_str, dst_str, labels):
+def generate_volmount_args(src_str, dst_str, vol_labels):
     """Generate a podman style volmount string"""
     vol_mount_str = f"{src_str}:{dst_str}"
-    if labels:
-        if not labels.startswith(":"):
+    if vol_labels:
+        if not vol_labels.startswith(":"):
             vol_mount_str += ":"
-        vol_mount_str += labels
+        vol_mount_str += vol_labels
     return ["-v", vol_mount_str]
 
 
 @pytest.mark.parametrize("not_safe", not_safe)
-def test_check_not_safe_to_mount_dir(not_safe):
+def test_check_not_safe_to_mount_dir(not_safe, mocker):
     """Ensure unsafe directories are not mounted"""
     with pytest.raises(ConfigurationError):
         bc = BaseConfig()
-        with patch("os.path.exists", return_value=True):
-            bc._update_volume_mount_paths(
-                args_list=[], src_mount_path=not_safe, dst_mount_path=None
-            )
+        mocker.patch("os.path.exists", return_value=True)
+        bc._update_volume_mount_paths(
+            args_list=[], src_mount_path=not_safe, dst_mount_path=None
+        )
 
 
 @pytest.mark.parametrize("not_safe", not_safe)
-def test_check_not_safe_to_mount_file(not_safe):
+def test_check_not_safe_to_mount_file(not_safe, mocker):
     """Ensure unsafe directories for a given file are not mounted"""
     file_path = os.path.join(not_safe, "file.txt")
     with pytest.raises(ConfigurationError):
         bc = BaseConfig()
-        with patch("os.path.exists", return_value=True):
-            bc._update_volume_mount_paths(
-                args_list=[], src_mount_path=file_path, dst_mount_path=None
-            )
+        mocker.patch("os.path.exists", return_value=True)
+        bc._update_volume_mount_paths(
+            args_list=[], src_mount_path=file_path, dst_mount_path=None
+        )
 
 
-@patch("os.path.exists", return_value=True)
-@patch("os.path.isdir", return_value=True)
 @pytest.mark.parametrize("path", dir_variations, ids=id_for_src)
-def test_duplicate_detection_dst(_mock_ope, _mock_isdir, path):
-    """Ensure no duplicate volumne mount entries are created"""
+def test_duplicate_detection_dst(path, mocker):
+    """Ensure no duplicate volume mount entries are created"""
+    mocker.patch("os.path.exists", return_value=True)
+    mocker.patch("os.path.isdir", return_value=True)
     base_config = BaseConfig()
 
-    def generate(args_list):
+    def generate():
         for entry in dir_variations:
             for label in labels:
                 base_config._update_volume_mount_paths(
@@ -111,21 +111,21 @@ def test_duplicate_detection_dst(_mock_ope, _mock_isdir, path):
                 )
 
     first_pass = []
-    generate(first_pass)
+    generate()
     second_pass = first_pass[:]
-    generate(second_pass)
+    generate()
     assert first_pass == second_pass
 
 
-@patch("os.path.exists", return_value=True)
-@patch("os.path.isdir", return_value=True)
 @pytest.mark.parametrize("labels", labels, ids=id_for_label)
 @pytest.mark.parametrize("path", dir_variations, ids=id_for_src)
-def test_no_dst_all_dirs(_mock_ope, _mock_isdir, path, labels):
-    """Ensure dst == src when not provided"""
+def test_no_dst_all_dirs(path, labels, mocker):
+    mocker.patch("os.path.exists", return_value=True)
+    mocker.patch("os.path.isdir", return_value=True)
+    # Ensure dst == src when not provided
     src_str = os.path.join(resolve_path(path.path), "")
     dst_str = src_str
-    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, labels=labels)
+    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, vol_labels=labels)
 
     result = []
     BaseConfig()._update_volume_mount_paths(
@@ -141,16 +141,16 @@ def test_no_dst_all_dirs(_mock_ope, _mock_isdir, path, labels):
     assert all(part.endswith('/') for part in result[1].split(':')[0:1]), explanation
 
 
-@patch("os.path.exists", return_value=True)
-@patch("os.path.isdir", return_value=True)
 @pytest.mark.parametrize("labels", labels, ids=id_for_label)
 @pytest.mark.parametrize("dst", dir_variations, ids=id_for_dst)
 @pytest.mark.parametrize("src", dir_variations, ids=id_for_src)
-def test_src_dst_all_dirs(_mock_ope, _mock_isdir, src, dst, labels):
-    """Ensure src and dest end with trailing slash"""
+def test_src_dst_all_dirs(src, dst, labels, mocker):
+    mocker.patch("os.path.exists", return_value=True)
+    mocker.patch("os.path.isdir", return_value=True)
+    # Ensure src and dest end with trailing slash
     src_str = os.path.join(resolve_path(src.path), "")
     dst_str = os.path.join(resolve_path(dst.path), "")
-    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, labels=labels)
+    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, vol_labels=labels)
 
     result = []
     BaseConfig()._update_volume_mount_paths(
@@ -168,22 +168,22 @@ def test_src_dst_all_dirs(_mock_ope, _mock_isdir, src, dst, labels):
 
 @pytest.mark.parametrize("labels", labels, ids=id_for_label)
 @pytest.mark.parametrize("path", dir_variations, ids=id_for_src)
-def test_src_dst_all_files(path, labels):
-    """Ensure file paths are tranformed correctly into dir paths"""
+def test_src_dst_all_files(path, labels, mocker):
+    """Ensure file paths are transformed correctly into dir paths"""
     src_str = os.path.join(resolve_path(path.path), "")
     dst_str = src_str
-    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, labels=labels)
+    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, vol_labels=labels)
 
     result = []
     src_file = os.path.join(path.path, "", "file.txt")
     dest_file = src_file
 
     base_config = BaseConfig()
-    with patch("os.path.exists", return_value=True):
-        with patch("os.path.isdir", return_value=False):
-            base_config._update_volume_mount_paths(
-                args_list=result, src_mount_path=src_file, dst_mount_path=dest_file, labels=labels
-            )
+    mocker.patch("os.path.exists", return_value=True)
+    mocker.patch("os.path.isdir", return_value=False)
+    base_config._update_volume_mount_paths(
+        args_list=result, src_mount_path=src_file, dst_mount_path=dest_file, labels=labels
+    )
 
     explanation = (
         f"provided: {src_file}:{dest_file}",
@@ -194,20 +194,20 @@ def test_src_dst_all_files(path, labels):
     assert all(part.endswith('/') for part in result[1].split(':')[0:1]), explanation
 
 
-@patch("os.path.exists", return_value=True)
-@patch("os.path.isdir", return_value=True)
 @pytest.mark.parametrize("relative", (".", "..", "../.."))
 @pytest.mark.parametrize("labels", labels, ids=id_for_label)
 @pytest.mark.parametrize("dst", dir_variations, ids=id_for_dst)
 @pytest.mark.parametrize("src", dir_variations, ids=id_for_src)
-def test_src_dst_all_relative_dirs(_mock_ope, _mock_isdir, src, dst, labels, relative):
-    """Ensure src is resolved and dest mapped to workdir when relative"""
+def test_src_dst_all_relative_dirs(src, dst, labels, relative, mocker):
+    mocker.patch("os.path.exists", return_value=True)
+    mocker.patch("os.path.isdir", return_value=True)
+    # Ensure src is resolved and dest mapped to workdir when relative
     relative_src = f"{relative}{src.path}"
     relative_dst = f"{relative}{dst.path}"
     workdir = "/workdir"
     src_str = os.path.join(resolve_path(relative_src), "")
     dst_str = os.path.join(resolve_path(os.path.join(workdir, relative_dst)), "")
-    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, labels=labels)
+    expected = generate_volmount_args(src_str=src_str, dst_str=dst_str, vol_labels=labels)
 
     result = []
     BaseConfig(container_workdir=workdir)._update_volume_mount_paths(
